@@ -6,10 +6,14 @@
 
 #ifndef ZCBOR_COMMON_H__
 #define ZCBOR_COMMON_H__
+
 #include <stdint.h>
 #include <stdbool.h>
 #include <stddef.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /** Convenience type that allows pointing to strings directly inside the payload
  *  without the need to copy out.
@@ -35,7 +39,7 @@ struct zcbor_string_fragment {
 #define ZCBOR_STRING_FRAGMENT_UNKNOWN_LENGTH SIZE_MAX
 
 #ifdef ZCBOR_VERBOSE
-#include <sys/printk.h>
+#include <zephyr/sys/printk.h>
 #define zcbor_trace() (printk("bytes left: %zu, byte: 0x%x, elem_count: 0x%" PRIxFAST32 ", err: %d, %s:%d\n",\
 	(size_t)state->payload_end - (size_t)state->payload, *state->payload, state->elem_count, \
 	state->constant_state ? state->constant_state->error : 0, __FILE__, __LINE__))
@@ -62,16 +66,24 @@ do { \
 		ZCBOR_FAIL(); \
 	} \
 } while(0)
+#define zcbor_assert_state(expr, ...) \
+do { \
+	if (!(expr)) { \
+		zcbor_print_assert(expr, __VA_ARGS__); \
+		ZCBOR_ERR(ZCBOR_ERR_ASSERTION); \
+	} \
+} while(0)
 #else
 #define zcbor_assert(expr, ...)
+#define zcbor_assert_state(expr, ...)
 #endif
 
 #ifndef MIN
 #define MIN(a, b) (((a) < (b)) ? (a) : (b))
 #endif
 
-#ifndef ARRAY_SIZE
-#define ARRAY_SIZE(arr) (sizeof(arr) / sizeof((arr)[0]))
+#ifndef ZCBOR_ARRAY_SIZE
+#define ZCBOR_ARRAY_SIZE(arr) (sizeof(arr) / sizeof((arr)[0]))
 #endif
 
 #if SIZE_MAX <= UINT64_MAX
@@ -386,4 +398,8 @@ bool zcbor_validate_string_fragments(struct zcbor_string_fragment *fragments,
 bool zcbor_splice_string_fragments(struct zcbor_string_fragment *fragments,
 		uint_fast32_t num_fragments, uint8_t *result, size_t *result_len);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* ZCBOR_COMMON_H__ */
