@@ -28,7 +28,7 @@ static uint_fast32_t additional_len(uint8_t additional)
 }
 
 /** Extract the major type, i.e. the first 3 bits of the header byte. */
-#define MAJOR_TYPE(header_byte) (((header_byte) >> 5) & 0x7)
+#define MAJOR_TYPE(header_byte) ((zcbor_major_type_t)(((header_byte) >> 5) & 0x7))
 
 /** Extract the additional info, i.e. the last 5 bits of the header byte. */
 #define ADDITIONAL(header_byte) ((header_byte) & 0x1F)
@@ -112,8 +112,8 @@ static bool value_extract(zcbor_state_t *state,
 		void *const result, uint_fast32_t result_len)
 {
 	zcbor_trace();
-	zcbor_assert(result_len != 0, "0-length result not supported.\r\n");
-	zcbor_assert(result != NULL, NULL);
+	zcbor_assert_state(result_len != 0, "0-length result not supported.\r\n");
+	zcbor_assert_state(result != NULL, NULL);
 
 	INITIAL_CHECKS();
 	ZCBOR_ERR_IF((state->elem_count == 0), ZCBOR_ERR_LOW_ELEM_COUNT);
@@ -158,7 +158,7 @@ static bool value_extract(zcbor_state_t *state,
 bool zcbor_int_decode(zcbor_state_t *state, void *result_int, size_t int_size)
 {
 	INITIAL_CHECKS();
-	uint8_t major_type = MAJOR_TYPE(*state->payload);
+	zcbor_major_type_t major_type = MAJOR_TYPE(*state->payload);
 	uint8_t *result_uint8 = (uint8_t *)result_int;
 	int8_t *result_int8 = (int8_t *)result_int;
 
@@ -215,16 +215,38 @@ bool zcbor_uint32_decode(zcbor_state_t *state, uint32_t *result)
 }
 
 
+bool zcbor_int32_expect_union(zcbor_state_t *state, int32_t result)
+{
+	if (!zcbor_union_elem_code(state)) {
+		ZCBOR_FAIL();
+	}
+	return zcbor_int32_expect(state, result);
+}
+
+
+bool zcbor_int64_expect_union(zcbor_state_t *state, int64_t result)
+{
+	if (!zcbor_union_elem_code(state)) {
+		ZCBOR_FAIL();
+	}
+	return zcbor_int64_expect(state, result);
+}
+
+
 bool zcbor_uint32_expect_union(zcbor_state_t *state, uint32_t result)
 {
-	zcbor_union_elem_code(state);
+	if (!zcbor_union_elem_code(state)) {
+		ZCBOR_FAIL();
+	}
 	return zcbor_uint32_expect(state, result);
 }
 
 
 bool zcbor_uint64_expect_union(zcbor_state_t *state, uint64_t result)
 {
-	zcbor_union_elem_code(state);
+	if (!zcbor_union_elem_code(state)) {
+		ZCBOR_FAIL();
+	}
 	return zcbor_uint64_expect(state, result);
 }
 
@@ -765,11 +787,11 @@ bool zcbor_float_expect(zcbor_state_t *state, double result)
 
 bool zcbor_any_skip(zcbor_state_t *state, void *result)
 {
-	zcbor_assert(result == NULL,
+	zcbor_assert_state(result == NULL,
 			"'any' type cannot be returned, only skipped.\r\n");
 
 	INITIAL_CHECKS();
-	uint8_t major_type = MAJOR_TYPE(*state->payload);
+	zcbor_major_type_t major_type = MAJOR_TYPE(*state->payload);
 	uint8_t additional = ADDITIONAL(*state->payload);
 	uint_fast32_t value;
 	uint_fast32_t num_decode;
@@ -911,7 +933,7 @@ bool zcbor_present_decode(uint_fast32_t *present,
 	uint_fast32_t num_decode;
 	bool retval = zcbor_multi_decode(0, 1, &num_decode, decoder, state, result, 0);
 
-	zcbor_assert(retval, "zcbor_multi_decode should not fail with these parameters.\r\n");
+	zcbor_assert_state(retval, "zcbor_multi_decode should not fail with these parameters.\r\n");
 
 	*present = num_decode;
 	return retval;
